@@ -42,26 +42,32 @@ async def startup():
     FastAPICache.init(MemcachedBackend(mc), prefix="fastapi-cache")
 
 
-def get_db():
+async def get_db():
     schema = "COLLECTOR"
     dbdata = dict(
-        dbuser=os.environ.get('%s_DBUSER' % schema),
-        dbpass=os.environ.get('%s_DBPASS' % schema),
-        dbname=os.environ.get('%s_DBNAME' % schema),
-        dbhost=os.environ.get('%s_DBHOST' % schema),
-        dbport=os.environ.get('%s_DBPORT' % schema)
+        dbuser=os.environ.get(f'{schema}_DBUSER'),
+        dbpass=os.environ.get(f'{schema}_DBPASS'),
+        dbname=os.environ.get(f'{schema}_DBNAME'),
+        dbhost=os.environ.get(f'{schema}_DBHOST'),
+        dbport=os.environ.get(f'{schema}_DBPORT')
     )
-
-    log_path = Path("~").resolve().absolute() / "log" / "api-orm.log"
-    session = SessionCollector(
-        log_path=log_path, active='true', server='bellaco', **dbdata)
+    collector_server = os.environ.get(f"{schema}_SERVER")
+    base_log_path = Path(os.getenv("ORM_LOG_PATH", "~")).resolve().absolute()
+    log_path = base_log_path / "log" / "api-orm.log"
+    session = None
     try:
+        session = SessionCollector(
+            log_path=log_path,
+            active='true',
+            server=collector_server,  # refiere al servidor que corre collector
+            **dbdata)
         yield session
     except Exception as e:
-        print("Error al crear sesion", e)
+        print("Error al crear sesion", e, log_path, dbdata)
     finally:
         print(now(), "Closing database connection")
-        session.close()
+        if session:
+            session.close()
 
 
 @app.get("/")
@@ -71,30 +77,38 @@ def read_root():
 
 @app.get("/stations")
 @cache(expire=300)
-async def all_stations(session: SessionCollector = Depends(get_db),
-                       code: Union[str, None] = None, name: Union[str, None] = None):
+async def all_stations(
+        session: SessionCollector = Depends(get_db),
+        code: Union[str, None] = None,
+        name: Union[str, None] = None):
     server_name = os.getenv("ORM_SERVER_NAME", "bellaco")
-    stations = session.get_station_data(server=server_name)
-    dataset = []
-    for item in stations:
-        station_id = item["id"]
-        dbdata = {d.priority: d for d in
-                  session.get_dbserver_data(station_id)}
-        item["dbdata"] = dbdata
-        dataset.append(item)
-    if code:
-        return [d for d in dataset if code.lower() in d["code"].lower()]
-    if name:
-        return [d for d in dataset if name.lower() in d["name"].lower()]
+    if session:
+        stations = session.get_station_data(server=server_name)
 
-    return dataset
+        dataset = []
+
+        for item in stations:
+            station_id = item["id"]
+            dbdata = {d["priority"]: d for d in
+                      session.get_dbserver_data(station_id)}
+            item["dbdata"] = dbdata
+            dataset.append(item)
+
+        if code:
+            return [d for d in dataset if code.lower() in d["code"].lower()]
+        if name:
+            return [d for d in dataset if name.lower() in d["name"].lower()]
+
+        return dataset
+    else:
+        return []
 
 
 @app.get("/databases")
 @cache(expire=300)
 async def all_databases(session: SessionCollector = Depends(get_db)):
     dbs = session.get_dbservers()
-    dataset = [d for d in dbs]
+    dataset = list(dbs)
     return dataset
 
 
@@ -102,7 +116,7 @@ async def all_databases(session: SessionCollector = Depends(get_db)):
 @cache(expire=300)
 async def all_networks(session: SessionCollector = Depends(get_db)):
     nets = session.get_network()
-    dataset = [d for d in nets]
+    dataset = list(nets)
     return dataset
 
 
@@ -110,7 +124,7 @@ async def all_networks(session: SessionCollector = Depends(get_db)):
 @cache(expire=300)
 async def all_servers(session: SessionCollector = Depends(get_db)):
     servers = session.get_server()
-    dataset = [d for d in servers]
+    dataset = list(servers)
     return dataset
 
 
@@ -118,7 +132,7 @@ async def all_servers(session: SessionCollector = Depends(get_db)):
 @cache(expire=300)
 async def all_protocols(session: SessionCollector = Depends(get_db)):
     queryset = session.get_protocol()
-    dataset = [d for d in queryset]
+    dataset = list(queryset)
     return dataset
 
 
@@ -126,7 +140,7 @@ async def all_protocols(session: SessionCollector = Depends(get_db)):
 @cache(expire=300)
 async def all_dbtypes(session: SessionCollector = Depends(get_db)):
     queryset = session.get_dbtype()
-    dataset = [d for d in queryset]
+    dataset = list(queryset)
     return dataset
 
 
