@@ -28,7 +28,7 @@ from networktools.geo import (radius, deg2rad, ecef2llh, llh2ecef)
 
 
 def get_llh(data):
-    ecef_keys = ["x","y","z"]
+    ecef_keys = ["x", "y", "z"]
     data['ecef_x'] = float(data['ecef_x'])
     data['ecef_y'] = float(data['ecef_y'])
     data['ecef_z'] = float(data['ecef_z'])
@@ -37,7 +37,7 @@ def get_llh(data):
     z = data['ecef_z']
     (lon, lat, h) = ecef2llh(x, y, z)
     data["position"] = {
-        "ecef"  : {
+        "ecef": {
             "x": data['ecef_x'],
             "y": data['ecef_y'],
             "z": data['ecef_z']
@@ -50,6 +50,7 @@ def get_llh(data):
         if key in data:
             del data[key]
 
+
 def object_as_dict(obj):
     return {c.key: getattr(obj, c.key)
             for c in inspect(obj).mapper.column_attrs}
@@ -68,7 +69,6 @@ class SessionHandle(CollectorSession):
         self.metadata = MetaData()
         code = kwargs.get('code', 'ORM')
         log_path = kwargs.get('log_path', './')
-        print("ORM log path", log_path)
         log_level = kwargs.get('log_level', 'INFO')
         hostname = kwargs.get('hostname', 'localhost')
         self.logger = LogFile(self.class_name,
@@ -241,13 +241,13 @@ class SessionCollector(SH):
         position_z = kwargs.get('ECEF_Z')
         protocol_host = kwargs.get('protocol_host')
         host = kwargs.get('host')
-        port = int(kwargs.get('port',0))
-        interface_port = int(kwargs.get('interface_port',80))
+        port = int(kwargs.get('port', 0))
+        interface_port = int(kwargs.get('interface_port', 80))
         db = kwargs.get('db')
         protocol = kwargs.get('protocol')
         server = kwargs.get('server_id', "atlas")
         active = kwargs.get('active', False)
-        network = kwargs.get("network_id","3g")
+        network = kwargs.get("network_id", "3g")
         instance = self.session.query(Station).filter_by(code=code).first()
 
         if instance:
@@ -322,7 +322,7 @@ class SessionCollector(SH):
         protocol = kwargs.get('protocol')
         server = kwargs.get('server_id', "atlas")
         active = kwargs.get('active', False)
-        network = kwargs.get("network_id","3g")
+        network = kwargs.get("network_id", "3g")
         position_x = kwargs.get('ECEF_X')
         position_y = kwargs.get('ECEF_Y')
         position_z = kwargs.get('ECEF_Z')
@@ -375,7 +375,7 @@ class SessionCollector(SH):
             for k, v in station.json.items():
                 val = instance.json.get(k)
                 if val:
-                    if v != val and k!='id':
+                    if v != val and k != 'id':
                         if k.startswith('ECEF'):
                             key = k.replace("ECEF", "position").lower()
                             differences[key] = v
@@ -421,7 +421,6 @@ class SessionCollector(SH):
         lon = center_point[1]
         point = "POINT(" + str(lon) + " " + str(lat) + ")"
         Q = "ST_GeogFromText(\'%s\')" % point
-        print(point)
         # u = self.session.query(Station).filter(
         #    functions.ST_DWithin(
         #        Station.position,
@@ -438,15 +437,20 @@ class SessionCollector(SH):
         if file_q.exists():
             sql_query_tpl = file_q.read_text()
             sql_query = sql_query_tpl.replace("[SERVER_ID]",
-                                              str(server.id)).replace("[ACTIVE]", active)
+                                              str(server.id)).replace("[ACTIVE]",
+                                                                      active)
+
             stmt = text(sql_query)
             result = self.session.execute(stmt)
             items = []
             for st in result:
-                item = dict(**st)
+                item = dict(**st._mapping)
                 code = item["code"]
                 protocol = item["protocol"]
                 item["table_name"] = f"{code}_{protocol}"
+                item["ecef_x"] = float(item["ecef_x"])
+                item["ecef_y"] = float(item["ecef_y"])
+                item["ecef_z"] = float(item["ecef_z"])
                 get_llh(item)
                 items.append(item)
             return items
@@ -503,8 +507,6 @@ class SessionCollector(SH):
         else:
             return None
 
-  
-
     # Server Instance
 
     def server(self, **kwargs):
@@ -553,7 +555,8 @@ class SessionCollector(SH):
 
     def get_server_id(self, name):
         # code is a unique value
-        u = self.session.query(ServerInstance).filter(ServerInstance.host_name.ilike(name)).all()
+        u = self.session.query(ServerInstance).filter(
+            ServerInstance.host_name.ilike(name)).all()
         if u:
             return u[0]
         else:
@@ -634,7 +637,8 @@ class SessionCollector(SH):
             hostname = kwargs.get('hostname')
             if 'type_name' in kwargs:
                 dbtype = kwargs.get('type_name')
-            instance = self.session.query(DBServer).filter_by(hostname=hostname).first()
+            instance = self.session.query(
+                DBServer).filter_by(hostname=hostname).first()
             if instance:
                 self.logger.info("DBSserver existe, %s" % instance)
                 return instance
@@ -642,15 +646,15 @@ class SessionCollector(SH):
                 db_e = self.get_dbtype_id(dbtype)
                 if db_e:
                     instance = DBServer(
-                                      path=path,
-                                      host=host,
-                                      port=port,
-                                      user=user,
-                                      passw=passw,
-                                      info=info,
-                                      dbtype_id=db_e.id,
-                                      dbname=dbname, 
-                                      hostname=hostname)
+                        path=path,
+                        host=host,
+                        port=port,
+                        user=user,
+                        passw=passw,
+                        info=info,
+                        dbtype_id=db_e.id,
+                        dbname=dbname,
+                        hostname=hostname)
                     self.create_dbserver(instance)
                     self.logger.info("Dbserver creada, %s" % instance)
                     return instance
@@ -706,21 +710,29 @@ class SessionCollector(SH):
             return None
 
     def get_dbserver_data(self, station_id):
+        fields = (
+            "station_id",
+            "priority",
+            "hostname",
+            "host",
+            "port",
+            "dbname")
         key = "[STATION_ID]"
         file_q = Path(self.path / "sql/dbserver_query.sql")
         if file_q.exists():
             sql_query = file_q.read_text().replace(key,
                                                    str(station_id))
             stmt = text(sql_query)
-            result = self.session.execute(stmt)
-            return result
+            result = self.session.execute(stmt).fetchall()
+            dobj = [dict(zip(fields, r)) for r in result]
+            return dobj
 
     def dbdata(self, **kwargs):
         try:
             station = kwargs.get('station')
             database = kwargs.get('dbserver')
             prioridad = kwargs.get("priority")
-            
+
             # buscar station, database
             station_id = self.get_station_id(station)
             database_id = self.get_dbserver_id(database)
@@ -729,7 +741,7 @@ class SessionCollector(SH):
             if (station_id and database_id) and not db_e:
                 instance = DBData(
                     station_id=station_id,
-                    database_id=database_id, 
+                    database_id=database_id,
                     priority=prioridad)
                 self.create_dbdata(instance)
                 self.logger.info("Dbdata creada, %s" % instance)
@@ -759,8 +771,8 @@ class SessionCollector(SH):
     def get_dbdata_by_id(self, station_id, database_id, prioridad):
         u = self.session.query(DBData).\
             filter_by(
-                database_id=database_id, 
-                station_id=station_id, 
+                database_id=database_id,
+                station_id=station_id,
                 priority=prioridad).all()
         if len(u) > 0:
             return u[0]
